phoopy-console
======

|Build Status| |Version| |Pyversions|

Console library for phoopy framework


.. |Build Status| image:: https://travis-ci.org/phoopy/phoopy-console.svg
   :target: https://travis-ci.org/phoopy/phoopy-console

.. |Version| image:: https://badge.fury.io/py/phoopy-console.svg
   :target: https://pypi.python.org/pypi/phoopy-console

.. |Pyversions| image:: https://img.shields.io/pypi/pyversions/phoopy-console.svg
   :target: https://pypi.python.org/pypi/phoopy-console
